@@ -161,7 +161,7 @@ my %FORMATS = (
      nanosleep              => "pp",
      newfstatat             => "ippi",
      open                   => "zxo",
-     openat                 => "ipiu",
+     openat                 => "fzxo",
      pause                  => "",
      perf_event_open        => "puiiu",
      personality            => "u",
